@@ -84,7 +84,7 @@ b_movie_get_type (void)
       movie_type = g_type_register_static (B_TYPE_OBJECT,
                                            "BMovie", &movie_info, 0);
     }
-  
+
   return movie_type;
 }
 
@@ -118,9 +118,7 @@ b_movie_init (BMovie *movie)
 static void
 b_movie_finalize (GObject *object)
 {
-  BMovie *movie;
-
-  movie = B_MOVIE (object);
+  BMovie *movie = B_MOVIE (object);
 
   b_movie_finalize_data (movie, TRUE);
 
@@ -226,7 +224,7 @@ b_movie_load_all (BMovie      *movie,
  * @filename: the name of the file to load
  * @lazy_load: whether to do lazy-loading, i.e. only load the header
  * @error: location to store the error occuring, or %NULL to ignore errors
- * 
+ *
  * Tries to load a #BMovie from the file pointed to by @filename. If
  * @lazy_load is %TRUE, only the header is loaded and no frames are stored.
  *
@@ -266,7 +264,7 @@ b_movie_new_from_file (const gchar  *filename,
  * b_movie_new_from_fd:
  * @fd: a UNIX file descriptor
  * @error: location to store the error occuring, or %NULL to ignore errors
- * 
+ *
  * Tries to load a #BMovie from the UNIX file descriptor @fd. Lazy
  * loading from file descriptors is not implemented since it doesn't
  * seem to make much sense.
@@ -304,14 +302,14 @@ b_movie_new_from_fd (gint     fd,
  * b_movie_load:
  * @movie: a #BMovie object
  * @error: location to store the error occuring, or %NULL to ignore errors
- * 
+ *
  * Assures that the frames of the @movie are loaded.
- * 
+ *
  * Return value: %TRUE if the movie was loaded successfully.
  **/
 gboolean
 b_movie_load (BMovie  *movie,
-              GError **error) 
+              GError **error)
 {
   g_return_val_if_fail (B_IS_MOVIE (movie), FALSE);
   g_return_val_if_fail (error == NULL || *error == NULL, FALSE);
@@ -324,7 +322,7 @@ b_movie_load (BMovie  *movie,
 
       g_return_val_if_fail (movie->frames == NULL && movie->n_frames == 0,
                             FALSE);
-      
+
       filename = b_object_get_filename (B_OBJECT (movie));
       if (!filename)
         {
@@ -332,12 +330,12 @@ b_movie_load (BMovie  *movie,
                        "Cannot load a movie that has no filename");
           return FALSE;
         }
-      
+
 
       io = g_io_channel_new_file (filename, "r", error);
       if (! io)
         return FALSE;
-      
+
       g_io_channel_set_encoding (io, NULL, NULL);
 
       success = ((b_movie_type_from_io_channel (io, error) ==
@@ -358,9 +356,9 @@ b_movie_load (BMovie  *movie,
 /**
  * b_movie_unload:
  * @movie: a #BMovie object
- * 
+ *
  * Unloads the frames of a movie.
- * 
+ *
  * The movie object counts how many times you call b_movie_load() and
  * b_movie_unload() and only really unloads the frames if
  * b_movie_unload() was called as often as b_movie_load(). Note that
@@ -368,13 +366,13 @@ b_movie_load (BMovie  *movie,
  * b_movie_load() unless lazy-loading was requested.
  **/
 void
-b_movie_unload (BMovie *movie) 
+b_movie_unload (BMovie *movie)
 {
   g_return_if_fail (B_IS_MOVIE (movie));
   g_return_if_fail (movie->load_count > 0);
 
   movie->load_count--;
-  
+
   if (movie->load_count == 0)
     b_movie_finalize_data (movie, FALSE);
 }
@@ -384,9 +382,9 @@ b_movie_unload (BMovie *movie)
  * @movie: a #BMovie object
  * @stream: a FILE stream ready for writing
  * @error: location to store the error occuring, or %NULL to ignore errors
- * 
+ *
  * Saves a #BMovie object to a @stream.
- * 
+ *
  * Return value: %TRUE on success or %FALSE otherwise
  **/
 gboolean
@@ -407,14 +405,14 @@ b_movie_save (BMovie  *movie,
  * @movie_type: the movie type to use for saving
  * @stream: a FILE stream ready for writing
  * @error: location to store the error occuring, or %NULL to ignore errors
- * 
+ *
  * Saves a #BMovie object to a @stream and allows to specify the file
  * format to use.
  *
  * The format is specified by passing a type derived from
  * #B_TYPE_MOVIE as @movie_type. At the moment B_TYPE_MOVIE_BML,
  * B_TYPE_MOVIE_BLM and B_TYPE_MOVIE_GIF are supported types.
- * 
+ *
  * Return value: %TRUE on success or %FALSE otherwise
  **/
 gboolean
@@ -431,7 +429,7 @@ b_movie_save_as (BMovie *movie,
   g_return_val_if_fail (stream != NULL, FALSE);
   g_return_val_if_fail (error == NULL || *error == NULL, FALSE);
 
-  if (!b_movie_load (movie, error))
+  if (! b_movie_load (movie, error))
     return FALSE;
 
   movie_class = g_type_class_ref (movie_type);
@@ -450,17 +448,17 @@ b_movie_save_as (BMovie *movie,
  * @movie: a loaded #BMovie object
  * @seed: an optional GList pointer that can speed up the search
  * @time: the time in milliseconds
- * 
+ *
  * Looks for the frame active after @time milliseconds.
- * 
+ *
  * If you are calling this function subsequentially with increasing
  * time values, you can speed up the search by passing the last return
  * value as the @seed parameter.
- * 
+ *
  * Return value: a GList pointer that has the frame as data or %NULL
  * if the time was out of the @movie's range.
  **/
-GList * 
+GList *
 b_movie_get_frame_at_time (BMovie *movie,
                            GList  *seed,
                            gint    time)
@@ -494,16 +492,16 @@ b_movie_get_frame_at_time (BMovie *movie,
 
 /**
  * b_movie_prepend_frame:
- * @movie: 
- * @duration: 
- * @data: 
- * 
+ * @movie:
+ * @duration:
+ * @data:
+ *
  * This is an internal function used by the movie loaders. It should
  * never be called from anywhere else.
  **/
 void
-b_movie_prepend_frame (BMovie       *movie, 
-                       gint          duration, 
+b_movie_prepend_frame (BMovie       *movie,
+                       gint          duration,
                        const guchar *data)
 {
   BMovieFrame *frame;
@@ -515,8 +513,8 @@ b_movie_prepend_frame (BMovie       *movie,
 
   frame->start    = movie->duration;
   frame->duration = duration;
-  frame->data     = g_malloc (movie->width * movie->height);
-  memcpy (frame->data, data, movie->width * movie->height);
+  frame->data     = g_memdup (data,
+                              movie->width * movie->height * movie->channels);
 
   movie->frames = g_list_prepend (movie->frames, frame);
   movie->n_frames++;
@@ -575,7 +573,7 @@ b_movie_type_from_io_channel (GIOChannel  *io,
                               GError     **error)
 {
   GType        movie_type = G_TYPE_NONE;
-  const gchar *magic      = NULL;   
+  const gchar *magic      = NULL;
   gsize        magic_len  = 1;
   gsize        len        = 0;
   gchar        buf[1024];
@@ -583,7 +581,7 @@ b_movie_type_from_io_channel (GIOChannel  *io,
   for (len = 0; len < sizeof (buf); len++)
     {
       GIOStatus  status;
-      
+
       status = g_io_channel_read_chars (io, buf + len, 1, NULL, error);
 
       if (status == G_IO_STATUS_ERROR || status == G_IO_STATUS_EOF)
@@ -628,7 +626,8 @@ b_movie_type_from_io_channel (GIOChannel  *io,
             continue;
 
           if (len == 5 &&
-              strncmp (buf, "GIF87a", 6) && strncmp (buf, "GIF89a", 6) == 0)
+              (strncmp (buf, "GIF87a", 6) == 0 ||
+               strncmp (buf, "GIF89a", 6) == 0))
             return B_TYPE_MOVIE_GIF;
 
           return G_TYPE_NONE;
@@ -645,7 +644,7 @@ b_movie_type_from_io_channel (GIOChannel  *io,
             {
               gboolean  ret;
               gchar    *encoding = b_parse_encoding (magic, magic_len);
-              
+
               ret = g_io_channel_set_encoding (io, encoding, error);
               g_free (encoding);
 
